==> peakrdl-regblock-0.13.0.tar.gz: peakrdl-regblock-0.13.0/src/peakrdl_regblock/cpuif/base.py <==
from typing import TYPE_CHECKING
import inspect
import os

import jinja2 as jj

from ..utils import get_always_ff_event, clog2, is_pow2, roundup_pow2

if TYPE_CHECKING:
    from ..exporter import RegblockExporter

class CpuifBase:

    # Path is relative to the location of the class that assigns this variable
    template_path = ""

    def __init__(self, exp:'RegblockExporter', data_width:int=32, addr_width:int=32):
        self.exp = exp
        self.reset = exp.top_node.cpuif_reset
        self.data_width = data_width
        self.addr_width = addr_width

    @property
    def data_width_bytes(self) -> int:
        return self.data_width // 8

    @property
    def port_declaration(self) -> str:
        raise NotImplementedError()


    def _get_template_path_class_dir(self) -> str:
        """
        Traverse up the MRO and find the first class that explicitly assigns
        template_path. Returns the directory that contains the class definition.
        """
        for cls in inspect.getmro(self.__class__):
            if "template_path" in cls.__dict__:
                class_dir = os.path.dirname(inspect.getfile(cls))
                return class_dir
        raise RuntimeError


    def get_implementation(self) -> str:
        class_dir = self._get_template_path_class_dir()
        loader = jj.FileSystemLoader(class_dir)
        jj_env = jj.Environment(
            loader=loader,
            undefined=jj.StrictUndefined,
        )

        context = {
            "cpuif": self,
            "get_always_ff_event": lambda resetsignal : get_always_ff_event(self.exp.dereferencer, resetsignal),
            "get_resetsignal": self.exp.dereferencer.get_resetsignal,
            "clog2": clog2,
            "is_pow2": is_pow2,
            "roundup_pow2": roundup_pow2,
        }

        template = jj_env.get_template(self.template_path)
        return template.render(context)

==> peakrdl-regblock-0.15.0.tar.gz: peakrdl-regblock-0.15.0/src/peakrdl_regblock/cpuif/base.py <==
from typing import TYPE_CHECKING
import inspect
import os

import jinja2 as jj

from ..utils import clog2, is_pow2, roundup_pow2

if TYPE_CHECKING:
    from ..exporter import RegblockExporter

class CpuifBase:

    # Path is relative to the location of the class that assigns this variable
    template_path = ""

    def __init__(self, exp:'RegblockExporter'):
        self.exp = exp
        self.reset = exp.ds.top_node.cpuif_reset

    @property
    def addr_width(self) -> int:
        return self.exp.ds.addr_width

    @property
    def data_width(self) -> int:
        return self.exp.ds.cpuif_data_width

    @property
    def data_width_bytes(self) -> int:
        return self.data_width // 8

    @property
    def port_declaration(self) -> str:
        raise NotImplementedError()


    def _get_template_path_class_dir(self) -> str:
        """
        Traverse up the MRO and find the first class that explicitly assigns
        template_path. Returns the directory that contains the class definition.
        """
        for cls in inspect.getmro(self.__class__):
            if "template_path" in cls.__dict__:
                class_dir = os.path.dirname(inspect.getfile(cls))
                return class_dir
        raise RuntimeError


    def get_implementation(self) -> str:
        class_dir = self._get_template_path_class_dir()
        loader = jj.FileSystemLoader(class_dir)
        jj_env = jj.Environment(
            loader=loader,
            undefined=jj.StrictUndefined,
        )

        context = {
            "cpuif": self,
            "get_always_ff_event": self.exp.dereferencer.get_always_ff_event,
            "get_resetsignal": self.exp.dereferencer.get_resetsignal,
            "clog2": clog2,
            "is_pow2": is_pow2,
            "roundup_pow2": roundup_pow2,
        }

        template = jj_env.get_template(self.template_path)
        return template.render(context)
